import 'package:cpt_notice_board/modules/notice_board/page/notice_board_page.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/widget_export.dart';
import 'package:cs_resources/generated/assets.dart';

import '../../../router/page/notice_board_page_router.dart';
import '../vm/announ_vm.dart';

import '../../announcement_detail/page/announcement_detail_page.dart';

@RoutePage()
class AnnounPage extends HookConsumerWidget {
  const AnnounPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const AnnounPageRoute());
    } else {
      appRouter.push(const AnnounPageRoute());
    }
  }

  Widget _buildItemLeftSection(BuildContext context, WidgetRef ref, item, _vm) {
    return Container(
      // color: Colors.blue,
      child: Text(
        maxLines: 2, // 设置最大行数为2
        overflow: TextOverflow.ellipsis, // 超出部分用省略号表示
        item['title'],
        style: const TextStyle(
            fontSize: 16.0,
            color: Colors.black,
            fontWeight: FontWeight.w700), // 设置字体大小
      ),
    );
  }
  Widget _buildItemRightSection(BuildContext context, WidgetRef ref, item, _vm) {
    return Container(
      // color: Colors.green,
      child: Text(
        item['price'],
        style: const TextStyle(
            fontSize: 14.0,
            color: Colors.black,
            fontWeight: FontWeight.w400), // 设置字体大小
      ),
    );
  }

  // listitem
  Widget _buildSaleItem(BuildContext context, WidgetRef ref, item, _vm) {
    return Container(
      
      decoration: const BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.all(Radius.circular(6.0)),
        boxShadow: [BoxShadow(color: Color.fromRGBO(184, 191, 217, 0.3), blurRadius: 6)],
      ),
      child: Column(
        children: [
          Container(
            width: MediaQuery.of(context).size.width - 30,
            height: 100,
            // margin: const EdgeInsets.only(left: 15, right: 15, top: 12.5),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                 _buildItemLeftSection(context, ref, item, _vm).marginOnly(bottom: 5),
                _buildItemRightSection(context, ref, item, _vm),
              ],
            ).paddingOnly(left: 20,right: 20),
          ).constrained(
            minHeight: 117.5,
          ),
        ],
      ).onTap(() {
        // 去详情
        // Navigator.push(
        //   context,
        //   MaterialPageRoute(builder: (context) => AnnouncementDetailPage()),
        // );
        AnnouncementDetailPage.startInstance(context: context);
        // _vm.goNewsDetail(item['title']);
      }),
    ).marginOnly(left: 15, bottom: 15, right: 15);
  }

  // list
  Widget _buildSaleList(BuildContext context, WidgetRef ref, _vm) {
    List itemsList = _vm.state.list.toList();
    return ListView.builder(
      itemCount: itemsList.length,
      itemBuilder: (context, index) {
        return _buildSaleItem(context, ref, itemsList[index], _vm);
      },
    );
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final _vm = ref.read(announVmProvider.notifier);

    return Scaffold(
      // appBar: AppBar(title: Text("资产")),
      body: Container(
          child: EasyRefresh(
        // 上拉加载
        onLoad: () async {
          Log.d("----onLoad");
          _vm.onLoadData();
        },
        // 下拉刷新
        onRefresh: () async {
          Log.d("----onRefresh");
          _vm.refreshListData();
        },
        child: Container(
            color: ColorUtils.string2Color('#F2F3F6'),
            padding: const EdgeInsets.only(top: 15),
            child: _buildSaleList(context, ref, _vm)),
      )),
    );
  }
}
